@@ -57,6 +57,8 @@ pub mod batch;
 #[cfg(any(
     feature = "google-cloud-bigquery-connection-v1",
     feature = "google-cloud-bigquery-connection-v1beta1",
+    feature = "google-cloud-bigquery-dataexchange-common",
+    feature = "google-cloud-bigquery-dataexchange-v1beta1",
     feature = "google-cloud-bigquery-datatransfer-v1",
     feature = "google-cloud-bigquery-logging-v1",
     feature = "google-cloud-bigquery-migration-v2alpha",
